@@ -20,60 +20,66 @@
  */
 
 
-/* $Id: mhash.c,v 1.34 2003/01/19 18:00:58 nmav Exp $ */
+/* $Id: mhash.c,v 1.39 2005/01/12 20:58:53 imipak Exp $ */
 
-#include <stdlib.h>
+#include <libdefs.h>
 
-#include "libdefs.h"
-
-#include "mhash_int.h"
+#include <mhash_int.h>
 
 #ifdef ENABLE_CRC32
-# include "mhash_crc32.h"
+# include <mhash_crc32.h>
 #endif
 
 #ifdef ENABLE_HAVAL
-# include "mhash_haval.h"
+# include <mhash_haval.h>
 #endif
 
 #ifdef ENABLE_MD5
-# include "mhash_md5.h"
+# include <mhash_md5.h>
 #endif
 
 #ifdef ENABLE_MD4
-# include "mhash_md4.h"
+# include <mhash_md4.h>
+#endif
+
+#ifdef ENABLE_MD2
+# include <mhash_md2.h>
 #endif
 
 #ifdef ENABLE_SHA1
-# include "mhash_sha1.h"
+# include <mhash_sha1.h>
 #endif
 
 #ifdef ENABLE_TIGER
-# include "mhash_tiger.h"
+# include <mhash_tiger.h>
 #endif
 
 #ifdef ENABLE_RIPEMD
-# include "mhash_ripemd.h"
+# include <mhash_ripemd.h>
 #endif
 
 #ifdef ENABLE_SHA256_SHA224
-# include "mhash_sha256_sha224.h"
+# include <mhash_sha256_sha224.h>
 #endif
 
 #ifdef ENABLE_SHA512_SHA384
-# include "mhash_sha512_sha384.h"
+# include <mhash_sha512_sha384.h>
 #endif
 
 #ifdef ENABLE_ADLER32
-# include "mhash_adler32.h"
+# include <mhash_adler32.h>
 #endif
 
 #ifdef ENABLE_GOST
-# include "mhash_gost.h"
+# include <mhash_gost.h>
 #endif
 
 #ifdef ENABLE_WHIRLPOOL
-# include "mhash_whirlpool.h"
+# include <mhash_whirlpool.h>
+#endif
+
+#ifdef ENABLE_SNEFRU
+# include <mhash_snefru.h>
 #endif
 
 /* 19/03/2000 Changes for better thread handling --nikos 
@@ -82,13 +88,14 @@
 
 #define MAX_BLOCK_SIZE 128
 
-#define MHASH_ENTRY(name, blksize, hash_pblock, state_size, init_func, \
-	hash_func, final_func, deinit_func) \
-	{ #name, name, blksize, hash_pblock, state_size, init_func,\
-		hash_func, final_func, deinit_func }
+#define MHASH_ENTRY(name, blksize, hash_pblock, state_size,		  \
+		    init_func, hash_func, final_func, deinit_func)	  \
+  { (mutils_word8 *) #name, name, blksize, hash_pblock, state_size,	  \
+      (INIT_FUNC) init_func, (HASH_FUNC) hash_func,			  \
+      (FINAL_FUNC) final_func, (DEINIT_FUNC) deinit_func }
 
 struct mhash_hash_entry {
-	char *name;
+	mutils_word8 *name;
 	hashid id;
 	size_t blocksize;
 	size_t hash_pblock;
@@ -102,14 +109,14 @@ struct mhash_hash_entry {
 
 static const mhash_hash_entry algorithms[] = {
 #ifdef ENABLE_CRC32
-	MHASH_ENTRY(MHASH_CRC32, 4, 0, sizeof(word32), mhash_clear_crc32, 
+	MHASH_ENTRY(MHASH_CRC32, 4, 0, sizeof(mutils_word32), mhash_clear_crc32, 
 		mhash_crc32, NULL, mhash_get_crc32),
-	MHASH_ENTRY(MHASH_CRC32B, 4, 0, sizeof(word32), mhash_clear_crc32,
+	MHASH_ENTRY(MHASH_CRC32B, 4, 0, sizeof(mutils_word32), mhash_clear_crc32,
 		mhash_crc32b, NULL, mhash_get_crc32),
 #endif
 
 #ifdef ENABLE_ADLER32
-	MHASH_ENTRY(MHASH_ADLER32, 4, 0, sizeof(word32), mhash_clear_adler32, 
+	MHASH_ENTRY(MHASH_ADLER32, 4, 0, sizeof(mutils_word32), mhash_clear_adler32, 
 		mhash_adler32, NULL, mhash_get_adler32),
 #endif
 
@@ -123,6 +130,11 @@ static const mhash_hash_entry algorithms[] = {
 		MD4Update, NULL, MD4Final),
 #endif
 
+#ifdef ENABLE_MD2
+	MHASH_ENTRY(MHASH_MD2, 16, 16, sizeof(MD2_CTX), md2_init,
+		md2_update, NULL, md2_digest),
+#endif
+
 #ifdef ENABLE_SHA1
 	MHASH_ENTRY(MHASH_SHA1, 20, 64, sizeof(SHA_CTX), sha_init, 
 		sha_update, sha_final, sha_digest),
@@ -184,15 +196,23 @@ static const mhash_hash_entry algorithms[] = {
 	MHASH_ENTRY(MHASH_WHIRLPOOL, 64, 64, sizeof(WHIRLPOOL_CTX), whirlpool_init, 
 		    whirlpool_update, whirlpool_final, whirlpool_digest),
 #endif
+
+#ifdef ENABLE_SNEFRU
+	MHASH_ENTRY(MHASH_SNEFRU128, 16, 64, sizeof(SNEFRU_CTX), snefru_init, 
+		    snefru128_update, snefru128_final, snefru128_digest),
+	MHASH_ENTRY(MHASH_SNEFRU256, 32, 64, sizeof(SNEFRU_CTX), snefru_init, 
+		    snefru256_update, snefru256_final, snefru256_digest),
+#endif
+
 	{0}
 };
 
 #define MHASH_LOOP(b) \
 	const mhash_hash_entry *p; \
-	for(p = algorithms; p->name != NULL; p++) { b ; }
+	for (p = algorithms; p->name != NULL; p++) { b ; }
 
 #define MHASH_ALG_LOOP(a) \
-	MHASH_LOOP( if(p->id == type) { a; break; } )
+	MHASH_LOOP( if (p->id == type) { a; break; } )
 
 #ifndef MMAX
 # define MMAX(x,y) (x>y?x:y)
@@ -215,13 +235,19 @@ WIN32DLL_DEFINE size_t mhash_get_block_size(hashid type)
 	return ret;
 }
 
-WIN32DLL_DEFINE int _mhash_get_state_size(hashid type)
+WIN32DLL_DEFINE size_t _mhash_get_state_size(hashid type)
 {
-	int size = -1;
+	/* Fixed: Valid state sizes that exceeded maximum
+	   positive value for integer would be returned as
+	   an error.
+	*/
+
+	size_t size = 0;
 
 	MHASH_ALG_LOOP(size = p->state_size);
 	return size;
 }
+
 WIN32DLL_DEFINE INIT_FUNC _mhash_get_init_func(hashid type)
 {
 	INIT_FUNC func = NULL;
@@ -252,38 +278,25 @@ WIN32DLL_DEFINE DEINIT_FUNC _mhash_get_deinit_func(hashid type)
 }
 
 
-/* function created in order for mhash to compile under WIN32 */
-char *mystrdup(char *str)
-{
-	char *ret;
-	if (str==NULL) return NULL;
-	
-	if ( (ret = malloc(strlen(str) + 1)) == NULL) return NULL;
-	strcpy(ret, str);
-
-	return ret;
-
-}
-
 WIN32DLL_DEFINE hashid mhash_get_mhash_algo( MHASH tmp) {
 	return tmp->algorithm_given;
 }
 
-WIN32DLL_DEFINE char *mhash_get_hash_name(hashid type)
+WIN32DLL_DEFINE mutils_word8 *mhash_get_hash_name(hashid type)
 {
-	char *ret = NULL;
+	mutils_word8 *ret = NULL;
 
 	/* avoid prefix */
-	MHASH_ALG_LOOP( ret = p->name);
+	MHASH_ALG_LOOP(ret = p->name);
 
 	if (ret!=NULL) ret += sizeof("MHASH_") - 1;
-	
-	return mystrdup(ret);
+
+	return mutils_strdup(ret);
 }
 
-WIN32DLL_DEFINE const char *mhash_get_hash_name_static(hashid type)
+WIN32DLL_DEFINE const mutils_word8 *mhash_get_hash_name_static(hashid type)
 {
-	char *ret = NULL;
+	mutils_word8 *ret = NULL;
 
 	/* avoid prefix */
 	MHASH_ALG_LOOP( ret = p->name);
@@ -296,48 +309,70 @@ WIN32DLL_DEFINE const char *mhash_get_hash_name_static(hashid type)
 MHASH mhash_cp(MHASH from) {
 MHASH ret;
 
-	if ( (ret = malloc(sizeof(MHASH_INSTANCE))) == NULL) return MHASH_FAILED;
-	memcpy(ret, from, sizeof(MHASH_INSTANCE));
+	ret = (MHASH) mutils_malloc(sizeof(MHASH_INSTANCE));
+ 
+	if (ret == NULL)
+		return MHASH_FAILED;
+
+	mutils_memcpy(ret, from, sizeof(MHASH_INSTANCE));
 	
 	/* copy the internal state also */
-	if ( (ret->state=malloc(ret->state_size)) == NULL) return MHASH_FAILED;
-	memcpy( ret->state, from->state, ret->state_size);
+	ret->state = (mutils_word8 *) mutils_malloc(ret->state_size);
+
+	if (ret->state == NULL) {
+		mutils_free(ret);
+		return MHASH_FAILED;
+	}
+
+	mutils_memcpy(ret->state, from->state, ret->state_size);
 	
 	/* copy the key in case of hmac*/
-	if (ret->hmac_key_size!=0) {
-		if ((ret->hmac_key=malloc(ret->hmac_key_size)) == NULL) return MHASH_FAILED;
-		memcpy(ret->hmac_key, from->hmac_key, ret->hmac_key_size);
+	if (ret->hmac_key_size != 0) {
+		ret->hmac_key = (mutils_word8 *) mutils_malloc(ret->hmac_key_size);
+
+		if (ret == NULL) {
+			mutils_free(ret->state);
+			mutils_free(ret);
+			return MHASH_FAILED;
+		}
+
+		mutils_memcpy(ret->hmac_key, from->hmac_key, ret->hmac_key_size);
 	}
 	return ret;
-
 }
+
 MHASH mhash_init_int(const hashid type)
 {
 	MHASH ret;
 	INIT_FUNC func;
 
-	if ( (ret = malloc( sizeof(MHASH_INSTANCE))) == NULL) return MHASH_FAILED;
-	ret->algorithm_given = type;
-	ret->hmac_key = NULL;
-	ret->state = NULL;
-	ret->hmac_key_size = 0;
-
-	ret->state_size = _mhash_get_state_size( type);
-	if (ret->state_size <= 0) {
-		free(ret);
+	ret = (MHASH) mutils_malloc(sizeof(MHASH_INSTANCE));
+	if (ret == NULL)
 		return MHASH_FAILED;
+
+	mutils_memset(ret, 0, sizeof(MHASH_INSTANCE));
+
+	ret->algorithm_given = type;
+
+	ret->state_size = _mhash_get_state_size(type);
+	if (ret->state_size == 0)
+	{
+		mutils_free(ret);
+		return(MHASH_FAILED);
 	}
 	
-	if ( (ret->state = malloc(ret->state_size)) == NULL) {
-		free(ret);
-		return MHASH_FAILED;
+	if ( (ret->state = mutils_malloc(ret->state_size)) == NULL)
+	{
+		mutils_free(ret);
+		return(MHASH_FAILED);
 	}
 	func = _mhash_get_init_func( type);
 	if (func!=NULL)
-		func( ret->state);
+		func(ret->state);
 	else {
-		free( ret);
-		return MHASH_FAILED;
+		mutils_free(ret->state);
+		mutils_free(ret);
+		return(MHASH_FAILED);
 	}
 
 	ret->hash_func = _mhash_get_hash_func( type);
@@ -349,34 +384,35 @@ MHASH mhash_init_int(const hashid type)
 }
 
 #define MIX32(a) \
-	(((unsigned long)((unsigned char *)(a))[0]) | \
-	(((unsigned long)((unsigned char *)(a))[1]) << 8)| \
-	(((unsigned long)((unsigned char *)(a))[2]) << 16)| \
-	(((unsigned long)((unsigned char *)(a))[3]) << 24))
-
+	(((mutils_word32)((mutils_word8 *)(a))[0]) | \
+	(((mutils_word32)((mutils_word8 *)(a))[1]) << 8)| \
+	(((mutils_word32)((mutils_word8 *)(a))[2]) << 16)| \
+	(((mutils_word32)((mutils_word8 *)(a))[3]) << 24))
 
 #ifdef WORDS_BIGENDIAN
-void mhash_32bit_conversion(word32 * ptr, size_t count)
+void mhash_32bit_conversion(mutils_word32 *ptr, size_t count)
 {
 	size_t i;
+	mutils_word32 *cptr = ptr;
 
-	for (i = 0; i < count; i++) {
-		ptr[i] = MIX32(&ptr[i]);
+	for (i = 0; i < count; i++, cptr++)
+	{
+		cptr = MIX32(cptr);
 	}
 }
 #else
 #define mhash_32bit_conversion(a,b)
 #endif
 
-/* plaintext should be a multiply of the algorithm's block size */
+/* plaintext should be a multiple of the algorithm's block size */
 
-int mhash(MHASH td, const void *plaintext, size_t size)
+mutils_boolean mhash(MHASH td, const void *plaintext, size_t size)
 {
 	
 	if (td->hash_func!=NULL)
 		td->hash_func( td->state, plaintext, size);
 
-	return 0;
+	return(MUTILS_OK);
 }
 
 
@@ -391,9 +427,9 @@ WIN32DLL_DEFINE
 		td->deinit_func( td->state, result);
 
 	if (NULL != td->state) {
-		free(td->state);
+		mutils_free(td->state);
 	}
-	free(td);
+	mutils_free(td);
 
 	return;
 }
@@ -402,21 +438,21 @@ WIN32DLL_DEFINE
     void *mhash_end_m(MHASH td, void *(*hash_malloc) (size_t))
 {
 	void *digest;
-	int size;
+	mutils_word32 size;
 
 	size = mhash_get_block_size( td->algorithm_given);
 	
-	digest = hash_malloc( size);
+	digest = mutils_malloc(size);
 	if (digest==NULL) return NULL;
 	
 	mhash_deinit( td, digest);
 	
-	return digest;
+	return(digest);
 }
 
 WIN32DLL_DEFINE void *mhash_end(MHASH td)
 {
-	return mhash_end_m(td, malloc);
+	return(mhash_end_m(td, malloc));
 }
 
 
@@ -426,7 +462,7 @@ WIN32DLL_DEFINE MHASH mhash_init(const hashid type)
 
 	ret = mhash_init_int(type);
 
-	return ret;
+	return(ret);
 }
 
 /* HMAC functions */
@@ -436,22 +472,23 @@ WIN32DLL_DEFINE size_t mhash_get_hash_pblock(hashid type)
 	size_t ret = 0;
 
 	MHASH_ALG_LOOP(ret = p->hash_pblock);
-	return ret;
+	return(ret);
 }
 
 WIN32DLL_DEFINE
-    int mhash_hmac_deinit(MHASH td, void *result)
+    mutils_error mhash_hmac_deinit(MHASH td, void *result)
 {
-	unsigned char *opad;
-	unsigned char _opad[MAX_BLOCK_SIZE];
+	mutils_word8 *opad;
+	mutils_word8 _opad[MAX_BLOCK_SIZE];
 	MHASH tmptd;
-	int i, opad_alloc = 0;
-	
+	mutils_word32 i;
+	mutils_word32 opad_alloc = 0;
 
-
-	if (td->hmac_block > MAX_BLOCK_SIZE) {
-		opad = malloc(td->hmac_block);
-		if (opad == NULL) return -1;
+	if (td->hmac_block > MAX_BLOCK_SIZE)
+	{
+		opad = mutils_malloc(td->hmac_block);
+		if (opad == NULL)
+			return(-MUTILS_SYSTEM_RESOURCE_ERROR);
 		opad_alloc = 1;
 	} else {
 		opad = _opad;
@@ -461,6 +498,7 @@ WIN32DLL_DEFINE
 	for (i = 0; i < td->hmac_key_size; i++) {
 		opad[i] = (0x5C) ^ td->hmac_key[i];
 	}
+
 	for (; i < td->hmac_block; i++) {
 		opad[i] = (0x5C);
 	}
@@ -468,27 +506,36 @@ WIN32DLL_DEFINE
 	tmptd = mhash_init(td->algorithm_given);
 	mhash(tmptd, opad, td->hmac_block);
 
-	if (td->final_func!=NULL)
-		td->final_func( td->state);
+	if (td->final_func != NULL)
+	{
+		td->final_func(td->state);
+	}
 
-	if (td->deinit_func!=NULL)
-		td->deinit_func( td->state, result);
+	if (td->deinit_func != NULL)
+	{
+		td->deinit_func(td->state, result);
+	}
 
-	if (result!=NULL)
+	if (result != NULL)
+	{
 		mhash(tmptd, result,
 		      mhash_get_block_size(td->algorithm_given));
+	}
 
-	free(td->state);
+	mutils_free(td->state);
 
-	if (opad_alloc!=0) free(opad);
-	
-	mhash_bzero(td->hmac_key, td->hmac_key_size);
-	free(td->hmac_key);
-	free(td);
+	if (opad_alloc!=0)
+	{
+		mutils_free(opad);
+	}
+
+	mutils_bzero(td->hmac_key, td->hmac_key_size);
+	mutils_free(td->hmac_key);
+	mutils_free(td);
 
 	mhash_deinit(tmptd, result);
 
-	return 0;
+	return(MUTILS_OK);
 }
 
 
@@ -500,12 +547,13 @@ WIN32DLL_DEFINE
 	digest =
 	    hash_malloc(mhash_get_block_size
 			(td->algorithm_given));
-	if (digest == NULL) return NULL;
 
-	mhash_hmac_deinit( td, digest);
-	
-	return digest;
+	if (digest == NULL)
+		return(NULL);
+
+	mhash_hmac_deinit(td, digest);
 	
+	return(digest);
 }
 
 WIN32DLL_DEFINE void *mhash_hmac_end(MHASH td)
@@ -513,18 +561,19 @@ WIN32DLL_DEFINE void *mhash_hmac_end(MHASH td)
 	return mhash_hmac_end_m(td, malloc);
 }
 
-
 WIN32DLL_DEFINE
-    MHASH mhash_hmac_init(const hashid type, void *key, int keysize,
-			  int block)
+    MHASH mhash_hmac_init(const hashid type, void *key, mutils_word32 keysize,
+			  mutils_word32 block)
 {
 	MHASH ret = MHASH_FAILED;
 	MHASH tmptd;
-	unsigned char *ipad;
-	unsigned char _ipad[MAX_BLOCK_SIZE];
-	int i, ipad_alloc=0;
+	mutils_word8 *ipad;
+	mutils_word8 _ipad[MAX_BLOCK_SIZE];
+	mutils_word32 i;
+	mutils_boolean ipad_alloc = MUTILS_FALSE;
 
-	if (block == 0) {
+	if (block == 0)
+	{
 		block = 64;	/* the default for ripemd,md5,sha-1 */
 	}
 
@@ -534,10 +583,12 @@ WIN32DLL_DEFINE
 		/* Initial hmac calculations */
 		ret->hmac_block = block;
 
-		if ( ret->hmac_block > MAX_BLOCK_SIZE) {
-			ipad = malloc(ret->hmac_block);
-			if (ipad == NULL) return MHASH_FAILED;
-			ipad_alloc = 1;
+		if ( ret->hmac_block > MAX_BLOCK_SIZE)
+		{
+			ipad = mutils_malloc(ret->hmac_block);
+			if (ipad == NULL)
+				return MHASH_FAILED;
+			ipad_alloc = MUTILS_TRUE;
 		} else {
 			ipad = _ipad;
 		}
@@ -548,8 +599,9 @@ WIN32DLL_DEFINE
 			ret->hmac_key_size = mhash_get_block_size(type);
 			ret->hmac_key = mhash_end(tmptd);
 		} else {
-			ret->hmac_key = calloc(1, ret->hmac_block);
-			memcpy(ret->hmac_key, key, keysize);
+			ret->hmac_key = mutils_malloc(ret->hmac_block);
+			mutils_bzero(ret->hmac_key, ret->hmac_block);
+			mutils_memcpy(ret->hmac_key, key, keysize);
 			ret->hmac_key_size = ret->hmac_block;
 		}
 
@@ -564,16 +616,11 @@ WIN32DLL_DEFINE
 
 		mhash(ret, ipad, ret->hmac_block);
 
-		if (ipad_alloc!=0) free(ipad);
+		if (ipad_alloc == MUTILS_TRUE)
+			mutils_free(ipad);
 	}
 
-
-	return ret;
-}
-
-WIN32DLL_DEFINE void mhash_free(void *ptr)
-{
-	free(ptr);
+	return(ret);
 }
 
 /*
@@ -586,42 +633,44 @@ WIN32DLL_DEFINE void mhash_free(void *ptr)
 
   Original version and idea by Blake Stephen <Stephen.Blake@veritect.com>
 */
-WIN32DLL_DEFINE int mhash_save_state_mem(MHASH td, void *_mem, int* mem_size )
+WIN32DLL_DEFINE mutils_error mhash_save_state_mem(MHASH td, void *_mem, mutils_word32 *mem_size )
 {
-	int tot_size, pos;
-	unsigned char* mem = _mem;
+	mutils_word32 tot_size;
+	mutils_word32 pos;
+	mutils_word8 *mem = _mem;
 	
 	tot_size = sizeof(td->algorithm_given) + sizeof(td->hmac_key_size)
 		+ sizeof(td->hmac_block) + td->hmac_key_size +
 		+ sizeof(td->state_size) + td->state_size;
 	
-	if ( *mem_size < tot_size) {
+	if ( *mem_size < tot_size)
+	{
 		*mem_size = tot_size;
-		return -1;
+		return(MUTILS_INVALID_INPUT_BUFFER);
 	}
 	
 	if ( mem != NULL) {
 		pos = 0;
-		memcpy( mem, &td->algorithm_given, sizeof(td->algorithm_given));
+		mutils_memcpy( mem, &td->algorithm_given, sizeof(td->algorithm_given));
 		pos = sizeof( td->algorithm_given);
 		
-		memcpy( &mem[pos], &td->hmac_key_size, sizeof(td->hmac_key_size));
+		mutils_memcpy( &mem[pos], &td->hmac_key_size, sizeof(td->hmac_key_size));
 		pos += sizeof(td->hmac_key_size);
 
-		memcpy( &mem[pos], &td->hmac_block, sizeof(td->hmac_block));
+		mutils_memcpy( &mem[pos], &td->hmac_block, sizeof(td->hmac_block));
 		pos += sizeof(td->hmac_block);
 
-		memcpy( &mem[pos], td->hmac_key, td->hmac_key_size);
+		mutils_memcpy( &mem[pos], td->hmac_key, td->hmac_key_size);
 		pos += td->hmac_key_size;
 
-		memcpy( &mem[pos], &td->state_size, sizeof(td->state_size));
+		mutils_memcpy( &mem[pos], &td->state_size, sizeof(td->state_size));
 		pos += sizeof(td->state_size);
 
-		memcpy( &mem[pos], td->state, td->state_size);
+		mutils_memcpy( &mem[pos], td->state, td->state_size);
 		pos += td->state_size;
 
 	}
-	return 0;
+	return(MUTILS_OK);
 }
 
 
@@ -631,63 +680,67 @@ WIN32DLL_DEFINE int mhash_save_state_mem(MHASH td, void *_mem, int* mem_size )
 */
 WIN32DLL_DEFINE MHASH mhash_restore_state_mem(void* _mem)
 {
-	unsigned char* mem = _mem;
+	mutils_word8 *mem = _mem;
 	hashid algorithm_given;
 	MHASH ret = MHASH_FAILED;
-	int pos;
+	mutils_word32 pos;
 
 	if (mem==NULL)
-		return ret;
+		return(ret);
 
-	memcpy( &algorithm_given, mem, sizeof(algorithm_given));
+	mutils_memcpy( &algorithm_given, mem, sizeof(algorithm_given));
 	
-	if ((ret = mhash_init(algorithm_given)) == MHASH_FAILED) {
-		return ret;
+	if ((ret = mhash_init(algorithm_given)) == MHASH_FAILED)
+	{
+		return(ret);
 	}
 
 	ret->algorithm_given = algorithm_given;
 	
 	pos = sizeof(algorithm_given);
 
- 	memcpy( &ret->hmac_key_size, &mem[pos], sizeof(ret->hmac_key_size));
+ 	mutils_memcpy( &ret->hmac_key_size, &mem[pos], sizeof(ret->hmac_key_size));
 	pos += sizeof( ret->hmac_key_size);
 		
-	memcpy( &ret->hmac_block, &mem[pos], sizeof(ret->hmac_block));
+	mutils_memcpy( &ret->hmac_block, &mem[pos], sizeof(ret->hmac_block));
 	pos += sizeof(ret->hmac_block);
 
-	if (ret->hmac_key_size != 0) {
+	if (ret->hmac_key_size != 0)
+	{
 		ret->hmac_key = malloc( ret->hmac_key_size);
-		if (ret->hmac_key==NULL) goto freeall;
+		if (ret->hmac_key==NULL)
+			goto freeall;
 	
-		memcpy( ret->hmac_key, &mem[pos], ret->hmac_key_size);
+		mutils_memcpy( ret->hmac_key, &mem[pos], ret->hmac_key_size);
 		pos += sizeof(ret->hmac_key_size);
 	}
 
-	memcpy( &ret->state_size, &mem[pos], sizeof(ret->state_size));
+	mutils_memcpy( &ret->state_size, &mem[pos], sizeof(ret->state_size));
 	pos += sizeof( ret->state_size);
 
-	ret->state = malloc( ret->state_size);
-	if (ret->state==NULL) goto freeall;
+	ret->state = mutils_malloc(ret->state_size);
+	if (ret->state==NULL)
+		goto freeall;
 
-	memcpy( ret->state, &mem[pos], ret->state_size);
+	mutils_memcpy( ret->state, &mem[pos], ret->state_size);
 	pos += ret->state_size;
 
 	ret->hash_func = _mhash_get_hash_func( algorithm_given);
 	ret->deinit_func = _mhash_get_deinit_func( algorithm_given);
 	ret->final_func = _mhash_get_final_func( algorithm_given);
 
-	return ret;
+	return(ret);
 
 	freeall:
 		/* This uses too much internals
 		 */
-		free( ret->state);
-		free( ret->hmac_key);
-		free( ret);
-		return MHASH_FAILED;
+		mutils_free(ret->state);
+		mutils_free(ret->hmac_key);
+		mutils_free(ret);
+		return(MHASH_FAILED);
 }
 
-#ifdef WIN32
+#if defined(WIN32) || defined (__CYGWIN__)
 WIN32DLL_DEFINE int main (void)
 {
        /* empty main function to avoid linker error (see cygwin FAQ) */
