@@ -19,9 +19,9 @@
 #include "libdefs.h"
 
 typedef struct {
-	word32 sum[8];
-	word32 hash[8];
-	word32 len[8];
+	mutils_word32 sum[8];
+	mutils_word32 hash[8];
+	mutils_word32 len[8];
 	byte partial[32];
 	size_t partial_bytes;
 } GostHashCtx;
