@@ -2,8 +2,8 @@
 #define MD4_H
 
 struct MD4Context {
-	word32 buf[4];
-	word32 bits[2];
+	mutils_word32 buf[4];
+	mutils_word32 bits[2];
 	unsigned char in[64];
 };
 
@@ -11,7 +11,7 @@ void MD4Init(struct MD4Context *context);
 void MD4Update(struct MD4Context *context, unsigned char const *buf,
 	       unsigned len);
 void MD4Final( struct MD4Context *context, unsigned char *digest);
-void MD4Transform(word32 buf[4], word32 const in[16]);
+void MD4Transform(mutils_word32 buf[4], mutils_word32 const in[16]);
 
 typedef struct MD4Context MD4_CTX;
 
