@@ -2,8 +2,8 @@
 #define MD5_H
 
 struct MD5Context {
-	word32 buf[4];
-	word32 bits[2];
+	mutils_word32 buf[4];
+	mutils_word32 bits[2];
 	unsigned char in[64];
 };
 
@@ -11,7 +11,7 @@ void MD5Init(struct MD5Context *context);
 void MD5Update(struct MD5Context *context, unsigned char const *buf,
 	       unsigned len);
 void MD5Final(struct MD5Context *context, unsigned char *digest);
-void MD5Transform(word32 buf[4], word32 const in[16]);
+void MD5Transform(mutils_word32 buf[4], mutils_word32 const in[16]);
 
 /*
  * This is needed to make RSAREF happy on some MS-DOS compilers.
