@@ -21,9 +21,9 @@
 typedef struct whirlpool_ctx
 {
   byte buffer[WHIRLPOOL_DATA_SIZE];	   /* buffer of data to hash */
-  word64 hashlen[4];                       /* number of hashed bits (256-bit) */
+  mutils_word64 hashlen[4];                       /* number of hashed bits (256-bit) */
   int index;		                   /* index to buffer */
-  word64 hash[WHIRLPOOL_DIGEST_SIZE/8];    /* the hashing state */
+  mutils_word64 hash[WHIRLPOOL_DIGEST_SIZE/8];    /* the hashing state */
 } WHIRLPOOL_CTX;
 
 void
